"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var enums_1 = require("../enums");
var structures_1 = require("../structures");
var utils_1 = require("../utils");
/**
 * @hidden
 */
var PacketHandler = /** @class */ (function () {
    function PacketHandler() {
    }
    /* -------------------------------------------------------------------------- */
    /*                                   General                                  */
    /* -------------------------------------------------------------------------- */
    PacketHandler[enums_1.identifiers.oldPacket] = function (conn, packet) {
        var data = packet.readUTF().split(String.fromCharCode(1));
        var a = data.splice(0, 1)[0];
        var ccc = (a.charCodeAt(0) << 8) | a.charCodeAt(1);
        this.handleOldPacket(conn, ccc, data);
    };
    PacketHandler[enums_1.identifiers.handshakeOk] = function (_conn, packet) {
        this.onlinePlayers = packet.readUnsignedInt();
        packet.readUTF(); // default language
        packet.readUTF(); // country;
        this.authServer = packet.readUnsignedInt();
        this.setLanguage(this.language);
        this.setSystemInfo("en", "Linux", "LNX 29,0,0,140");
        this.startHeartbeat();
    };
    PacketHandler[enums_1.identifiers.loginReady] = function () {
        this.emit("loginReady");
    };
    PacketHandler[enums_1.identifiers.fingerprint] = function (conn, packet) {
        conn.fingerprint = packet.readByte();
    };
    PacketHandler[enums_1.identifiers.bulle] = function (_conn, packet) {
        var code = packet.readUnsignedShort();
        this.handleTribulle(code, packet);
    };
    PacketHandler[enums_1.identifiers.bulleConnection] = function (_conn, packet) {
        var _this = this;
        var timestamp = packet.readUnsignedInt();
        var playerId = packet.readUnsignedInt();
        var pcode = packet.readUnsignedInt();
        var host = packet.readUTF();
        packet
            .readUTF()
            .split("-")
            .map(function (port) { return ~~port; }); // port
        if (this.bulle && this.bulle.open)
            this.bulle.close();
        this.bulle = new utils_1.Connection(this.identificationKeys, this.messageKeys);
        this.bulle.on("data", function (conn, packet) {
            _this.handlePacket(conn, packet);
        });
        this.bulle.on("connect", function () {
            _this.bulle.send(enums_1.identifiers.bulleConnection, new utils_1.ByteArray()
                .writeUnsignedInt(timestamp)
                .writeUnsignedInt(playerId)
                .writeUnsignedInt(pcode));
        });
        this.bulle.connect(host, this.ports[0]);
    };
    PacketHandler[enums_1.identifiers.profile] = function (_conn, packet) {
        this.emit("profile", new structures_1.Profile(this).read(packet));
    };
    /* -------------------------------------------------------------------------- */
    /*                                Login Result                                */
    /* -------------------------------------------------------------------------- */
    PacketHandler[enums_1.identifiers.loggedIn] = function (_conn, packet) {
        this.playerId = packet.readUnsignedInt();
        this.name = packet.readUTF();
        this.playingTime = packet.readUnsignedInt();
        this.connectionTime = new Date().getTime();
        this.community = packet.readByte();
        this.pcode = packet.readUnsignedInt();
        this.emit("login", this.name, this.pcode);
    };
    PacketHandler[enums_1.identifiers.loginError] = function (_conn, packet) {
        this.emit("loginError", packet.readUnsignedByte(), packet.readUTF(), packet.readUTF());
    };
    /* -------------------------------------------------------------------------- */
    /*                                    Room                                    */
    /* -------------------------------------------------------------------------- */
    PacketHandler[enums_1.identifiers.luaChatLog] = function (_conn, packet) {
        this.emit("luaLog", packet.readUTF());
    };
    PacketHandler[enums_1.identifiers.roomMessage] = function (_conn, packet) {
        var player = this.room.getPlayer(packet.readUTF());
        if (!player)
            return;
        var content = packet.readUTF();
        var message = new structures_1.RoomMessage(this, player, content);
        this.emit("roomMessage", message);
    };
    PacketHandler[enums_1.identifiers.roomChange] = function (_conn, packet) {
        var before = this.room;
        var isPublic = packet.readBoolean();
        var name = packet.readUTF();
        var language = packet.readUTF();
        this.room = new structures_1.Room(this, isPublic, name, language);
        this.emit("roomChange", this.room, before);
    };
    PacketHandler[enums_1.identifiers.roomPlayerList] = function (_conn, packet) {
        var before = this.room.playerList;
        this.room.playerList = [];
        var length = packet.readUnsignedShort();
        for (var i = 0; i < length; i++) {
            var player = new structures_1.RoomPlayer(this).read(packet);
            this.room.playerList.push(player);
        }
        this.player = this.room.getPlayer(this.pcode);
        this.emit("roomPlayersUpdate", this.room.playerList, before);
    };
    PacketHandler[enums_1.identifiers.roomPlayerEnter] = function (_conn, packet) {
        var player = new structures_1.RoomPlayer(this).read(packet);
        if (this.room.getPlayer(player.pcode)) {
            this.room.updatePlayer(player);
            this.emit("roomPlayerUpdate", player, this.room.getPlayer(player.pcode));
        }
        else {
            this.room.addPlayer(player);
            this.emit("roomPlayerEnter", player);
        }
    };
    PacketHandler[enums_1.identifiers.roomPlayerWin] = function (_conn, packet) {
        packet.readByte();
        var player = this.room.getPlayer(packet.readInt());
        if (player) {
            player.score = packet.readShort();
            var order = packet.readByte();
            var time = packet.readShort() / 100;
            this.emit("roomPlayerEnterHole", player, order, time);
        }
    };
    PacketHandler[enums_1.identifiers.roomPlayerGetCheese] = function (_conn, packet) {
        var player = this.room.getPlayer(packet.readInt());
        if (player) {
            player.hasCheese = packet.readBoolean();
            this.emit("roomPlayerGetCheese", player);
        }
    };
    return PacketHandler;
}());
exports.default = PacketHandler;
