import { ValueOf, ByteArray } from "../utils";
import { genders } from "../enums";
import Client from "../client";
import { Tribe, Player } from ".";
/** Represents a tribe member */
export default class Member extends Player {
    /**
     * The member's tribe
     */
    tribe: Tribe;
    /**
     * The member's id
     */
    id: number;
    /**
     * The member's gender
     */
    gender: ValueOf<typeof genders>;
    /**
     * The player's last connection time
     */
    lastConnection: number;
    /**
     * The rank id of the member
     */
    rankId: number;
    /**
     * the Game ID the player is playing
     */
    gameId: number;
    /**
     * The room name of the player (if they are online)
     */
    roomName: string;
    /**
     * @hidden
     */
    constructor(client: Client, member?: Partial<Member>);
    /**
     * Returns member data from a packet
     *
     * @hidden
     */
    read(packet: ByteArray): this;
    /**
     * The rank of the member
     */
    get rank(): unknown;
    /**
     * If the player is connected
     */
    get isConnected(): boolean;
}
